@@ -39,6 +39,7 @@ typedef struct
 	int automapoverlay;
 	int automaprotate;
 	int automapstats;
+	int bobfactor;
 	int brightmaps;
 	int centerweapon;
 	int coloredblood;
@@ -121,6 +122,14 @@ enum
     NUM_ASPECTRATIOS,
 };
 
+enum
+{
+    BOBFACTOR_FULL,
+    BOBFACTOR_75,
+    BOBFACTOR_OFF,
+    NUM_BOBFACTORS,
+};
+
 enum
 {
     BRIGHTMAPS_OFF,
@@ -133,10 +142,8 @@ enum
 enum
 {
     CENTERWEAPON_OFF,
-    CENTERWEAPON_HOR,
-    CENTERWEAPON_HORVER,
+    CENTERWEAPON_CENTER,
     CENTERWEAPON_BOB,
-    CENTERWEAPON_BOB2,
     NUM_CENTERWEAPON,
 };
 
