@@ -76,6 +76,7 @@ static int recvtic;
 // The number of tics that have been run (using RunTic) so far.
 
 int gametic;
+int oldleveltime; // [crispy] check if leveltime keeps tickin'
 
 // When set to true, a single tic is run each time TryRunTics() is called.
 // This is used for -timedemo mode.
@@ -348,21 +349,10 @@ void D_StartNetGame(net_gamesettings_t *settings,
     //!
     // @category net
     //
-    // Use new network client sync code rather than the classic
-    // sync code. This is currently disabled by default because it
-    // has some bugs.
+    // Use original network client sync code rather than the improved
+    // sync code.
     //
-    if (M_CheckParm("-newsync") > 0)
-        settings->new_sync = 1;
-    else
-        settings->new_sync = 0;
-
-    // TODO: New sync code is not enabled by default because it's
-    // currently broken. 
-    //if (M_CheckParm("-oldsync") > 0)
-    //    settings->new_sync = 0;
-    //else
-    //    settings->new_sync = 1;
+    settings->new_sync = !M_ParmExists("-oldsync");
 
     //!
     // @category net
@@ -461,6 +451,7 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
 
         net_loop_client_module.InitClient();
         addr = net_loop_client_module.ResolveAddress(NULL);
+        NET_ReferenceAddress(addr);
     }
     else
     {
@@ -497,6 +488,7 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
         {
             net_sdl_module.InitClient();
             addr = net_sdl_module.ResolveAddress(myargv[i+1]);
+            NET_ReferenceAddress(addr);
 
             if (addr == NULL)
             {
@@ -519,6 +511,7 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
         }
 
         printf("D_InitNetGame: Connected to %s\n", NET_AddrToString(addr));
+        NET_ReleaseAddress(addr);
 
         // Wait for launch message received from server.
 
@@ -689,6 +682,11 @@ void TryRunTics (void)
     int	availabletics;
     int	counts;
 
+    // [AM] If we've uncapped the framerate and there are no tics
+    //      to run, return early instead of waiting around.
+    extern int leveltime;
+    #define return_early (crispy->uncapped && counts == 0 && leveltime > oldleveltime && screenvisible)
+
     // get real tics
     entertic = I_GetTime() / ticdup;
     realtics = entertic - oldentertics;
@@ -715,6 +713,11 @@ void TryRunTics (void)
     if (new_sync)
     {
 	counts = availabletics;
+
+        // [AM] If we've uncapped the framerate and there are no tics
+        //      to run, return early instead of waiting around.
+        if (return_early)
+            return;
     }
     else
     {
@@ -728,7 +731,7 @@ void TryRunTics (void)
 
         // [AM] If we've uncapped the framerate and there are no tics
         //      to run, return early instead of waiting around.
-        if (counts == 0 && crispy->uncapped && gametic && screenvisible)
+        if (return_early)
             return;
 
         if (counts < 1)
