@@ -208,6 +208,12 @@ static mline_t cross_mark[] = {
     { { -R, 0 }, { R, 0 } },
     { { 0, -R }, { 0, R } },
 };
+static mline_t square_mark[] = {
+    { { -R,  0 }, {  0,  R } },
+    { {  0,  R }, {  R,  0 } },
+    { {  R,  0 }, {  0, -R } },
+    { {  0, -R }, { -R,  0 } },
+};
 #undef R
 
 
@@ -738,12 +744,12 @@ AM_Responder
         {
             // [crispy] keep the map static in overlay mode
             // if not following the player
-            if (!followplayer && !crispy->automapoverlay) m_paninc.x = FTOM(F_PANINC);
+            if (!followplayer && !crispy->automapoverlay) m_paninc.x = crispy->fliplevels ? -FTOM(F_PANINC) : FTOM(F_PANINC);
             else rc = false;
         }
         else if (key == key_map_west)     // pan left
         {
-            if (!followplayer && !crispy->automapoverlay) m_paninc.x = -FTOM(F_PANINC);
+            if (!followplayer && !crispy->automapoverlay) m_paninc.x = crispy->fliplevels ? FTOM(F_PANINC) : -FTOM(F_PANINC);
             else rc = false;
         }
         else if (key == key_map_north)    // pan up
@@ -1164,9 +1170,9 @@ AM_drawFline
     }
 
 #ifndef CRISPY_TRUECOLOR
-#define PUTDOT(xx,yy,cc) fb[(yy)*f_w+(xx)]=(cc)
+#define PUTDOT(xx,yy,cc) fb[(yy)*f_w+(flipscreenwidth[xx])]=(cc)
 #else
-#define PUTDOT(xx,yy,cc) fb[(yy)*f_w+(xx)]=(colormaps[(cc)])
+#define PUTDOT(xx,yy,cc) fb[(yy)*f_w+(flipscreenwidth[xx])]=(colormaps[(cc)])
 #endif
 
     dx = fl->b.x - fl->a.x;
@@ -1246,8 +1252,9 @@ void AM_drawGrid(int color)
     {
 	start -= m_h / 2;
     }
+    // [crispy] fix losing grid lines near the automap boundary
     if ((start-bmaporgx)%(MAPBLOCKUNITS<<FRACBITS))
-	start += (MAPBLOCKUNITS<<FRACBITS)
+	start += // (MAPBLOCKUNITS<<FRACBITS)
 	    - ((start-bmaporgx)%(MAPBLOCKUNITS<<FRACBITS));
     end = m_x + m_w;
     if (crispy->automaprotate)
@@ -1279,8 +1286,9 @@ void AM_drawGrid(int color)
     {
 	start -= m_w / 2;
     }
+    // [crispy] fix losing grid lines near the automap boundary
     if ((start-bmaporgy)%(MAPBLOCKUNITS<<FRACBITS))
-	start += (MAPBLOCKUNITS<<FRACBITS)
+	start += // (MAPBLOCKUNITS<<FRACBITS)
 	    - ((start-bmaporgy)%(MAPBLOCKUNITS<<FRACBITS));
     end = m_y + m_h;
     if (crispy->automaprotate)
@@ -1685,6 +1693,16 @@ AM_drawThings
 		 pt.x, pt.y);
 	    }
 	    else
+	    // [crispy] draw blood splats and puffs as small squares
+	    if (t->type == MT_BLOOD || t->type == MT_PUFF)
+	    {
+	    AM_drawLineCharacter
+		(square_mark, arrlen(square_mark),
+		 t->radius >> 2, t->angle,
+		 (t->type == MT_BLOOD) ? REDS : GRAYS,
+		 pt.x, pt.y);
+	    }
+	    else
 	    {
 	    AM_drawLineCharacter
 		(thintriangle_guy, arrlen(thintriangle_guy),
@@ -1735,7 +1753,7 @@ void AM_drawMarks(void)
 	    {
 		AM_rotatePoint(&pt);
 	    }
-	    fx = (CXMTOF(pt.x) >> crispy->hires) - 1;
+	    fx = (flipscreenwidth[CXMTOF(pt.x)] >> crispy->hires) - 1;
 	    fy = (CYMTOF(pt.y) >> crispy->hires) - 2;
 	    if (fx >= f_x && fx <= (f_w >> crispy->hires) - w && fy >= f_y && fy <= (f_h >> crispy->hires) - h)
 		V_DrawPatch(fx, fy, marknums[i]);
