@@ -245,7 +245,7 @@ boolean D_Display (void)
 
         // [crispy] Crispy HUD
         if (screenblocks >= CRISPY_HUD)
-            ST_Drawer(false, false);
+            ST_Drawer(false, true);
     }
 
     // [crispy] in automap overlay mode,
@@ -268,13 +268,6 @@ boolean D_Display (void)
 	R_FillBackScreen ();    // draw the pattern into the back screen
     }
 
-    // [crispy] in automap overlay mode,
-    // draw the automap beneath the bezel
-    if (automapactive && crispy->automapoverlay)
-    {
-	AM_Drawer ();
-    }
-
     // see if the border needs to be updated to the screen
     if (gamestate == GS_LEVEL && (!automapactive || crispy->automapoverlay) && scaledviewwidth != SCREENWIDTH)
     {
@@ -301,9 +294,10 @@ boolean D_Display (void)
     oldgamestate = wipegamestate = gamestate;
     
     // [crispy] in automap overlay mode,
-    // draw the HUD on top of everything else
+    // draw the automap and HUD on top of everything else
     if (automapactive && crispy->automapoverlay)
     {
+	AM_Drawer ();
 	HU_Drawer ();
 
 	// [crispy] force redraw of status bar and border
@@ -324,7 +318,7 @@ boolean D_Display (void)
 	    y = 4;
 	else
 	    y = (viewwindowy >> crispy->hires)+4;
-	V_DrawPatchShadow2((viewwindowx >> crispy->hires) + ((scaledviewwidth >> crispy->hires) - 68) / 2, y,
+	V_DrawPatchDirect((viewwindowx >> crispy->hires) + ((scaledviewwidth >> crispy->hires) - 68) / 2, y,
                           W_CacheLumpName (DEH_String("M_PAUSE"), PU_CACHE));
     }
 
@@ -414,6 +408,7 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_automapoverlay",  &crispy->automapoverlay);
     M_BindIntVariable("crispy_automaprotate",   &crispy->automaprotate);
     M_BindIntVariable("crispy_automapstats",    &crispy->automapstats);
+    M_BindIntVariable("crispy_bobfactor",       &crispy->bobfactor);
     M_BindIntVariable("crispy_brightmaps",      &crispy->brightmaps);
     M_BindIntVariable("crispy_centerweapon",    &crispy->centerweapon);
     M_BindIntVariable("crispy_coloredblood",    &crispy->coloredblood);
@@ -1073,6 +1068,7 @@ static struct
     const char *cmdline;
     GameVersion_t version;
 } gameversions[] = {
+    {"Doom 1.2",             "1.2",        exe_doom_1_2},
     {"Doom 1.666",           "1.666",      exe_doom_1_666},
     {"Doom 1.7/1.7a",        "1.7",        exe_doom_1_7},
     {"Doom 1.8",             "1.8",        exe_doom_1_8},
@@ -1100,9 +1096,9 @@ static void InitGameVersion(void)
     // @arg <version>
     // @category compat
     //
-    // Emulate a specific version of Doom.  Valid values are "1.666",
-    // "1.7", "1.8", "1.9", "ultimate", "final", "final2", "hacx" and
-    // "chex".
+    // Emulate a specific version of Doom.  Valid values are "1.2", 
+    // "1.666", "1.7", "1.8", "1.9", "ultimate", "final", "final2",
+    // "hacx" and "chex".
     //
 
     p = M_CheckParmWithArgs("-gameversion", 1);
@@ -1165,6 +1161,13 @@ static void InitGameVersion(void)
                     status = true;
                     switch (demoversion)
                     {
+                        case 0:
+                        case 1:
+                        case 2:
+                        case 3:
+                        case 4:
+                            gameversion = exe_doom_1_2;
+                            break;
                         case 106:
                             gameversion = exe_doom_1_666;
                             break;
@@ -1203,6 +1206,12 @@ static void InitGameVersion(void)
             gameversion = exe_final;
         }
     }
+
+    // Deathmatch 2.0 did not exist until Doom v1.4
+    if (gameversion <= exe_doom_1_2 && deathmatch == 2)
+    {
+        deathmatch = 1;
+    }
     
     // The original exe does not support retail - 4th episode not supported
 
@@ -2085,18 +2094,6 @@ void D_DoomMain (void)
     I_PrintStartupBanner(gamedescription);
     PrintDehackedBanners();
 
-    // Freedoom's IWADs are Boom-compatible, which means they usually
-    // don't work in Vanilla (though FreeDM is okay). Show a warning
-    // message and give a link to the website.
-    if (gamevariant == freedoom)
-    {
-        printf(" WARNING: You are playing using one of the Freedoom IWAD\n"
-               " files, which might not work in this port. See this page\n"
-               " for more information on how to play using Freedoom:\n"
-               "   https://www.chocolate-doom.org/wiki/index.php/Freedoom\n");
-        I_PrintDivider();
-    }
-
     DEH_printf("I_Init: Setting up machine state.\n");
     I_CheckIsScreensaver();
     I_InitTimer();
@@ -2280,13 +2277,14 @@ void D_DoomMain (void)
     if (p > 0)
     {
         crispy->fliplevels = !crispy->fliplevels;
+        crispy->flipweapons = !crispy->flipweapons;
     }
 
     p = M_CheckParm("-flipweapons");
 
     if (p > 0)
     {
-        crispy->flipweapons = true;
+        crispy->flipweapons = !crispy->flipweapons;
     }
 
     // Check for load game parameter
