@@ -39,6 +39,7 @@
 #include "i_system.h"
 #include "i_timer.h"
 #include "i_input.h"
+#include "i_swap.h"
 #include "i_video.h"
 
 #include "p_setup.h"
@@ -135,6 +136,7 @@ int             totalleveltimes;        // [crispy] CPhipps - total time for all
 int             demostarttic;           // [crispy] fix revenant internal demo bug
  
 char           *demoname;
+char           *orig_demoname; // [crispy] the name originally chosen for the demo, i.e. without "-00000"
 boolean         demorecording; 
 boolean         longtics;               // cph's doom 1.91 longtics hack
 boolean         lowres_turn;            // low resolution turning for longtics
@@ -764,6 +766,12 @@ void G_BuildTiccmd (ticcmd_t* cmd, int maketic)
 	cmd->buttons = BT_SPECIAL | BTS_SAVEGAME | (savegameslot<<BTS_SAVESHIFT); 
     } 
 
+    if (crispy->fliplevels)
+    {
+	cmd->angleturn = -cmd->angleturn;
+	cmd->sidemove = -cmd->sidemove;
+    }
+
     // low-res turning
 
     if (lowres_turn)
@@ -1315,7 +1323,7 @@ void G_PlayerFinishLevel (int player)
     p->centering =
     p->jumpTics =
     p->recoilpitch = p->oldrecoilpitch =
-    p->psp_dy = p->psp_dy_max = 0;
+    p->psp_dy_max = 0;
 } 
  
 
@@ -1782,10 +1790,15 @@ void G_DoCompleted (void)
     // statcheck regression testing.
     if (gamemode == commercial)
     {
-        // map33 has no official time: initialize to zero
+        // map33 reads its par time from beyond the cpars[] array
         if (gamemap == 33)
         {
-            wminfo.partime = 0;
+            int cpars32;
+
+            memcpy(&cpars32, DEH_String(GAMMALVL0), sizeof(int));
+            cpars32 = LONG(cpars32);
+
+            wminfo.partime = TICRATE*cpars32;
         }
         // [crispy] support [PARS] sections in BEX files
         else if (bex_cpars[gamemap-1])
@@ -1847,7 +1860,11 @@ void G_DoCompleted (void)
     viewactive = false; 
     automapactive = false; 
 
+    // [crispy] no statdump output for ExM8
+    if (gamemode == commercial || gamemap != 8)
+    {
     StatCopy(&wminfo);
+    }
  
     WI_Start (&wminfo); 
 } 
@@ -2175,6 +2192,16 @@ G_DeferedInitNew
     d_map = map; 
     G_ClearSavename();
     gameaction = ga_newgame; 
+
+    // [crispy] if a new game is started during demo recording, start a new demo
+    if (demorecording)
+    {
+	G_CheckDemoStatus();
+	Z_Free(demoname);
+
+	G_RecordDemo(orig_demoname);
+	G_BeginRecording();
+    }
 } 
 
 
@@ -2334,7 +2361,8 @@ G_InitNew
 
     // [crispy] CPhipps - total time for all completed levels
     totalleveltimes = 0;
-    demostarttic = 0; // [crispy] fix revenant internal demo bug
+    defdemotics = 0;
+    demostarttic = gametic; // [crispy] fix revenant internal demo bug
 
     viewactive = true;
 
@@ -2450,12 +2478,6 @@ void G_ReadDemoTiccmd (ticcmd_t* cmd)
 
     cmd->buttons = (unsigned char)*demo_p++; 
 
-    if (crispy->fliplevels)
-    {
-	cmd->sidemove *= (const signed char) -1;
-	cmd->angleturn *= (const short) -1;
-    }
-
     // [crispy] increase demo tics counter
     // applies to both recording and playback,
     // because G_WriteDemoTiccmd() calls G_ReadDemoTiccmd() once
@@ -2498,12 +2520,6 @@ void G_WriteDemoTiccmd (ticcmd_t* cmd)
 { 
     byte *demo_start;
 
-    if (crispy->fliplevels)
-    {
-	cmd->sidemove *= (const signed char) -1;
-	cmd->angleturn *= (const short) -1;
-    }
-
     if (gamekeydown[key_demo_quit])           // press q to end demo recording 
 	G_CheckDemoStatus (); 
 
@@ -2562,17 +2578,26 @@ void G_RecordDemo (char *name)
     size_t demoname_size;
     int i;
     int maxsize;
+
+    // [crispy] demo file name suffix counter
+    static unsigned int j = 0;
     FILE *fp = NULL;
 
+    // [crispy] the name originally chosen for the demo, i.e. without "-00000"
+    if (!orig_demoname)
+    {
+	orig_demoname = name;
+    }
+
     usergame = false;
     demoname_size = strlen(name) + 5 + 6; // [crispy] + 6 for "-00000"
     demoname = Z_Malloc(demoname_size, PU_STATIC, NULL);
     M_snprintf(demoname, demoname_size, "%s.lmp", name);
 
     // [crispy] prevent overriding demos by adding a file name suffix
-    for (i = 0; i <= 99999 && (fp = fopen(demoname, "rb")) != NULL; i++)
+    for ( ; j <= 99999 && (fp = fopen(demoname, "rb")) != NULL; j++)
     {
-	M_snprintf(demoname, demoname_size, "%s-%05d.lmp", name, i);
+	M_snprintf(demoname, demoname_size, "%s-%05d.lmp", name, j);
 	fclose (fp);
     }
 
@@ -2600,8 +2625,6 @@ int G_VanillaVersionCode(void)
 {
     switch (gameversion)
     {
-        case exe_doom_1_2:
-            I_Error("Doom 1.2 does not have a version code!");
         case exe_doom_1_666:
             return 106;
         case exe_doom_1_7:
@@ -2636,7 +2659,7 @@ void G_BeginRecording (void)
     {
         *demo_p++ = DOOM_191_VERSION;
     }
-    else
+    else if (gameversion > exe_doom_1_2)
     {
         *demo_p++ = G_VanillaVersionCode();
     }
@@ -2644,11 +2667,14 @@ void G_BeginRecording (void)
     *demo_p++ = gameskill; 
     *demo_p++ = gameepisode; 
     *demo_p++ = gamemap; 
-    *demo_p++ = deathmatch; 
-    *demo_p++ = respawnparm;
-    *demo_p++ = fastparm;
-    *demo_p++ = nomonsters;
-    *demo_p++ = consoleplayer;
+    if (longtics || gameversion > exe_doom_1_2)
+    {
+        *demo_p++ = deathmatch; 
+        *demo_p++ = respawnparm;
+        *demo_p++ = fastparm;
+        *demo_p++ = nomonsters;
+        *demo_p++ = consoleplayer;
+    }
 	 
     for (i=0 ; i<MAXPLAYERS ; i++) 
 	*demo_p++ = playeringame[i]; 		 
@@ -2720,6 +2746,7 @@ void G_DoPlayDemo (void)
     skill_t skill;
     int i, lumpnum, episode, map;
     int demoversion;
+    boolean olddemo = false;
     int lumplength; // [crispy]
 
     // [crispy] in demo continue mode free the obsolete demo buffer
@@ -2745,6 +2772,12 @@ void G_DoPlayDemo (void)
 
     demoversion = *demo_p++;
 
+    if (demoversion >= 0 && demoversion <= 4)
+    {
+        olddemo = true;
+        demo_p--;
+    }
+
     longtics = false;
 
     // Longtics demos use the modified format that is generated by cph's
@@ -2754,7 +2787,8 @@ void G_DoPlayDemo (void)
     {
         longtics = true;
     }
-    else if (demoversion != G_VanillaVersionCode())
+    else if (demoversion != G_VanillaVersionCode() &&
+             !(gameversion <= exe_doom_1_2 && olddemo))
     {
         const char *message = "Demo is from a different game version!\n"
                               "(read %i, should be %i)\n"
@@ -2783,12 +2817,24 @@ void G_DoPlayDemo (void)
     skill = *demo_p++; 
     episode = *demo_p++; 
     map = *demo_p++; 
-    deathmatch = *demo_p++;
-    respawnparm = *demo_p++;
-    fastparm = *demo_p++;
-    nomonsters = *demo_p++;
-    consoleplayer = *demo_p++;
-	
+    if (!olddemo)
+    {
+        deathmatch = *demo_p++;
+        respawnparm = *demo_p++;
+        fastparm = *demo_p++;
+        nomonsters = *demo_p++;
+        consoleplayer = *demo_p++;
+    }
+    else
+    {
+        deathmatch = 0;
+        respawnparm = 0;
+        fastparm = 0;
+        nomonsters = 0;
+        consoleplayer = 0;
+    }
+    
+        
     for (i=0 ; i<MAXPLAYERS ; i++) 
 	playeringame[i] = *demo_p++; 
 
@@ -2948,7 +2994,15 @@ boolean G_CheckDemoStatus (void)
 	M_WriteFile (demoname, demobuffer, demo_p - demobuffer); 
 	Z_Free (demobuffer); 
 	demorecording = false; 
+	// [crispy] if a new game is started during demo recording, start a new demo
+	if (gameaction != ga_newgame)
+	{
 	I_Error ("Demo %s recorded",demoname); 
+	}
+	else
+	{
+	    fprintf(stderr, "Demo %s recorded\n",demoname);
+	}
     } 
 	 
     return false; 
