@@ -827,7 +827,7 @@ void HU_Drawer(void)
     }
 
     // [crispy] translucent messages for translucent HUD
-    if (screenblocks > CRISPY_HUD && (!automapactive || crispy->automapoverlay))
+    if (screenblocks > CRISPY_HUD + 1 && (!automapactive || crispy->automapoverlay))
 	dp_translucent = true;
 
     if (secret_on && !menuactive)
@@ -895,7 +895,7 @@ void HU_Drawer(void)
     else
     if (demorecording && (crispy->demotimer & DEMOTIMER_RECORD))
     {
-	ST_DrawDemoTimer(defdemotics);
+	ST_DrawDemoTimer(leveltime);
     }
 
     // [crispy] demo progress bar
@@ -1003,7 +1003,7 @@ void HU_Ticker(void)
 			    message_counter = HU_MSGTIMEOUT;
 			    if ( gamemode == commercial )
 			      S_StartSound(0, sfx_radio);
-			    else
+			    else if (gameversion > exe_doom_1_2)
 			      S_StartSound(0, sfx_tink);
 			}
 			HUlib_resetIText(&w_inputbuffer[i]);
