@@ -32,6 +32,13 @@ multiitem_t multiitem_aspectratio[NUM_ASPECTRATIOS] =
     {ASPECTRATIO_16_10, "16:10"},
 };
 
+multiitem_t multiitem_bobfactor[NUM_BOBFACTORS] =
+{
+    {BOBFACTOR_FULL, "full"},
+    {BOBFACTOR_75, "75%"},
+    {BOBFACTOR_OFF, "off"},
+};
+
 multiitem_t multiitem_brightmaps[NUM_BRIGHTMAPS] =
 {
     {BRIGHTMAPS_OFF, "none"},
@@ -43,10 +50,8 @@ multiitem_t multiitem_brightmaps[NUM_BRIGHTMAPS] =
 multiitem_t multiitem_centerweapon[NUM_CENTERWEAPON] =
 {
     {CENTERWEAPON_OFF, "off"},
-    {CENTERWEAPON_HOR, "horizontal"},
-    {CENTERWEAPON_HORVER, "centered"},
+    {CENTERWEAPON_CENTER, "centered"},
     {CENTERWEAPON_BOB, "bobbing"},
-    {CENTERWEAPON_BOB2, "bobbing/2"},
 };
 
 multiitem_t multiitem_coloredhud[NUM_COLOREDHUD] =
@@ -142,7 +147,6 @@ extern void EnableLoadingDisk (void);
 extern void P_SegLengths (boolean contrast_only);
 extern void R_ExecuteSetViewSize (void);
 extern void R_InitLightTables (void);
-extern void S_UpdateSndChannels (void);
 extern void I_ReInitGraphics (int reinit);
 
 static void M_CrispyToggleAspectRatioHook (void)
@@ -167,6 +171,12 @@ void M_CrispyToggleAutomapstats(int choice)
     crispy->automapstats = (crispy->automapstats + 1) % NUM_WIDGETS;
 }
 
+void M_CrispyToggleBobfactor(int choice)
+{
+    choice = 0;
+    crispy->bobfactor = (crispy->bobfactor + 1) % NUM_BOBFACTORS;
+}
+
 void M_CrispyToggleBrightmaps(int choice)
 {
     choice = 0;
@@ -499,6 +509,8 @@ void M_CrispyToggleSoundMono(int choice)
 {
     choice = 0;
     crispy->soundmono = !crispy->soundmono;
+
+    S_UpdateStereoSeparation();
 }
 
 void M_CrispyToggleTranslucency(int choice)
