@@ -24,9 +24,10 @@
 #include "doomstat.h"
 #include "doomtype.h"
 #include "m_misc.h"
-#include "p_local.h"
 #include "p_extsaveg.h"
+#include "p_local.h"
 #include "p_saveg.h"
+#include "p_setup.h"
 #include "s_sound.h"
 #include "s_musinfo.h"
 #include "z_zone.h"
@@ -48,13 +49,16 @@ char *savewadfilename = NULL;
 
 static void P_WriteWadFileName (const char *key)
 {
-	M_snprintf(line, MAX_LINE_LEN, "%s %s\n", key, maplumpinfo->wad_file->basename);
+	M_snprintf(line, MAX_LINE_LEN, "%s %s\n", key, W_WadNameForLump(maplumpinfo));
 	fputs(line, save_stream);
 }
 
 static void P_ReadWadFileName (const char *key)
 {
-	if (!savewadfilename)
+	if (!savewadfilename &&
+	    // [crispy] only check if loaded from the menu,
+	    // we have no chance to show a dialog otherwise
+	    startloadgame == -1)
 	{
 		if (sscanf(line, "%s", string) == 1 &&
 		    !strncmp(string, key, MAX_STRING_LEN))
@@ -197,6 +201,40 @@ static void P_ReadSoundTarget (const char *key)
 	}
 }
 
+// sector->oldspecial
+
+static void P_WriteOldSpecial (const char *key)
+{
+	int i;
+	sector_t *sector;
+
+	for (i = 0, sector = sectors; i < numsectors; i++, sector++)
+	{
+		if (sector->oldspecial)
+		{
+			M_snprintf(line, MAX_LINE_LEN, "%s %d %d\n",
+			           key,
+			           i,
+			           sector->oldspecial);
+			fputs(line, save_stream);
+		}
+	}
+}
+
+static void P_ReadOldSpecial (const char *key)
+{
+	int sector, oldspecial;
+
+	if (sscanf(line, "%s %d %d\n",
+	           string,
+	           &sector,
+	           &oldspecial) == 3 &&
+	    !strncmp(string, key, MAX_STRING_LEN))
+	{
+		sectors[sector].oldspecial = oldspecial;
+	}
+}
+
 // buttonlist[]
 
 extern void P_StartButton (line_t *line, bwhere_e w, int texture, int time);
@@ -353,31 +391,43 @@ static void P_ReadPlayersLookdir (const char *key)
 
 static void P_WriteMusInfo (const char *key)
 {
-	if (musinfo.current_item > 0)
+	if (musinfo.current_item > 0 && musinfo.items[0] > 0)
 	{
-		char *lump;
+		char lump[9], orig[9];
 
-		lump = lumpinfo[musinfo.current_item]->name;
+		strncpy(lump, lumpinfo[musinfo.current_item]->name, 8);
+		strncpy(orig, lumpinfo[musinfo.items[0]]->name, 8);
 
-		M_snprintf(line, MAX_LINE_LEN, "%s %s\n", key, lump);
+		M_snprintf(line, MAX_LINE_LEN, "%s %s %s\n", key, lump, orig);
 		fputs(line, save_stream);
 	}
 }
 
 static void P_ReadMusInfo (const char *key)
 {
-	char lump[9] = {0};
+	int items;
+	char lump[9] = {0}, orig[9] = {0};
 
-	if (sscanf(line, "%s %s", string, lump) == 2 &&
+	items = sscanf(line, "%s %s %s", string, lump, orig);
+
+	if (items >= 2 &&
 	    !strncmp(string, key, MAX_STRING_LEN))
 	{
 		int i;
 
 		if ((i = W_CheckNumForName(lump)) > 0)
 		{
+			memset(&musinfo, 0, sizeof(musinfo));
 			musinfo.current_item = i;
+			musinfo.from_savegame = true;
 			S_ChangeMusInfoMusic(i, true);
 		}
+
+		if (items == 3 &&
+		    (i = W_CheckNumForName(orig)) > 0)
+		{
+			musinfo.items[0] = i;
+		}
 	}
 }
 
@@ -397,11 +447,12 @@ static const extsavegdata_t extsavegdata[] =
 	{"totalleveltimes", P_WriteTotalLevelTimes, P_ReadTotalLevelTimes, 1},
 	{"fireflicker", P_WriteFireFlicker, P_ReadFireFlicker, 1},
 	{"soundtarget", P_WriteSoundTarget, P_ReadSoundTarget, 1},
+	{"oldspecial", P_WriteOldSpecial, P_ReadOldSpecial, 1},
 	{"button", P_WriteButton, P_ReadButton, 1},
 	{"braintarget", P_WriteBrainTarget, P_ReadBrainTarget, 1},
 	{"markpoints", P_WriteMarkPoints, P_ReadMarkPoints, 1},
 	{"playerslookdir", P_WritePlayersLookdir, P_ReadPlayersLookdir, 1},
-	{"musinfo", P_WriteMusInfo, P_ReadMusInfo, 1},
+	{"musinfo", P_WriteMusInfo, P_ReadMusInfo, 0},
 };
 
 void P_WriteExtendedSaveGameData (void)
