@@ -115,7 +115,7 @@ static statenum_t P_LatestSafeState(statenum_t state)
 	}
 
 	// [crispy] a state with -1 tics never changes
-	if (states[state].tics == -1)
+	if (states[state].tics == -1 || state == states[state].nextstate)
 	{
 	    break;
 	}
@@ -384,7 +384,10 @@ void P_ZMovement (mobj_t* mo)
 		// and utter appropriate sound.
 		mo->player->deltaviewheight = mo->momz>>3;
 		// [crispy] squat down weapon sprite as well
-		mo->player->psp_dy_max = mo->momz>>2;
+		if (crispy->weaponsquat)
+		{
+			mo->player->psp_dy_max = mo->momz>>2;
+		}
 		// [crispy] center view if not using permanent mouselook
 		if (!crispy->mouselook)
 		    mo->player->centering = true;
