@@ -18,6 +18,7 @@
 //
 
 #include <stdio.h>
+#include <stdlib.h> // [crispy] calloc()
 
 #include "deh_main.h"
 #include "i_swap.h"
@@ -1236,14 +1237,6 @@ void R_InitColormaps (void)
 
 	W_ReleaseLumpName("PLAYPAL");
     }
-
-#ifndef CRISPY_TRUECOLOR
-    // [crispy] initialize tinttable for V_DrawPatchShadow2
-    {
-	extern byte *tinttable;
-	tinttable = cr[CR_DARK];
-    }
-#endif
 }
 
 
