@@ -37,6 +37,7 @@
 #include "p_local.h" // [crispy] MLOOKUNIT
 #include "r_local.h"
 #include "r_sky.h"
+#include "st_stuff.h" // [crispy] ST_refreshBackground()
 
 
 
@@ -772,6 +773,9 @@ boolean		setsizeneeded;
 int		setblocks;
 int		setdetail;
 
+// [crispy] lookup table for horizontal screen coordinates
+int		flipscreenwidth[MAXWIDTH];
+int		*flipviewwidth;
 
 void
 R_SetViewSize
@@ -888,6 +892,17 @@ void R_ExecuteSetViewSize (void)
 	    scalelight[i][j] = colormaps + level*256;
 	}
     }
+
+    // [crispy] lookup table for horizontal screen coordinates
+    for (i = 0, j = SCREENWIDTH - 1; i < SCREENWIDTH; i++, j--)
+    {
+	flipscreenwidth[i] = crispy->fliplevels ? j : i;
+    }
+
+    flipviewwidth = flipscreenwidth + (crispy->fliplevels ? (SCREENWIDTH - scaledviewwidth) : 0);
+
+    // [crispy] forcefully initialize the status bar backing screen
+    ST_refreshBackground(true);
 }
 
 
@@ -1059,7 +1074,11 @@ void R_RenderPlayerView (player_t* player)
     // [crispy] flashing HOM indicator
     V_DrawFilledBox(viewwindowx, viewwindowy,
         scaledviewwidth, viewheight,
+#ifndef CRISPY_TRUECOLOR
         crispy->flashinghom ? (176 + (gametic % 16)) : 0);
+#else
+        colormaps[crispy->flashinghom ? (176 + (gametic % 16)) : 0]);
+#endif
 
     // check for new console commands.
     NetUpdate ();
