@@ -293,6 +293,11 @@ static st_stateenum_t	st_gamestate;
 // whether left-side main status bar is active
 static boolean		st_statusbaron;
 
+// [crispy] distinguish classic status bar with background and player face from Crispy HUD
+static boolean		st_crispyhud;
+static boolean		st_classicstatusbar;
+static boolean		st_statusbarface;
+
 // whether status bar chat is active
 static boolean		st_chat;
 
@@ -314,6 +319,9 @@ static boolean		st_fragson;
 // main bar left
 static patch_t*		sbar;
 
+// main bar right, for doom 1.0
+static patch_t*		sbarr;
+
 // 0-9, tall numbers
 static patch_t*		tallnum[10];
 
@@ -419,6 +427,10 @@ cheatseq_t cheat_choppers = CHEAT("idchoppers", 0);
 cheatseq_t cheat_clev = CHEAT("idclev", 2);
 cheatseq_t cheat_mypos = CHEAT("idmypos", 0);
 
+// [crispy] pseudo cheats to eat up the first digit typed after a cheat expecting two parameters
+cheatseq_t cheat_mus1 = CHEAT("idmus", 1);
+cheatseq_t cheat_clev1 = CHEAT("idclev", 1);
+
 // [crispy] new cheats
 cheatseq_t cheat_weapon = CHEAT("tntweap", 1);
 cheatseq_t cheat_massacre = CHEAT("tntem", 0); // [crispy] PrBoom+
@@ -457,18 +469,19 @@ static inline int cht_CheckCheatSP (cheatseq_t *cht, char key)
 //
 void ST_Stop(void);
 
-void ST_refreshBackground(void)
+void ST_refreshBackground(boolean force)
 {
 
-    if (screenblocks >= CRISPY_HUD && (!automapactive || crispy->automapoverlay))
-        return;
-
-    if (st_statusbaron)
+    if (st_classicstatusbar || force)
     {
         V_UseBuffer(st_backing_screen);
 
 	V_DrawPatch(ST_X, 0, sbar);
 
+	// draw right side of bar if needed (Doom 1.0)
+	if (sbarr)
+	    V_DrawPatch(ST_ARMSBGX, 0, sbarr);
+
 	// [crispy] back up arms widget background
 	if (!deathmatch)
 	    V_DrawPatch(ST_ARMSBGX, 0, armsbg);
@@ -478,6 +491,7 @@ void ST_refreshBackground(void)
 
         V_RestoreBuffer();
 
+	if (!force)
 	V_CopyRect(ST_X, 0, st_backing_screen, ST_WIDTH, ST_HEIGHT, ST_X, ST_Y);
     }
 
@@ -624,6 +638,30 @@ static boolean WeaponAvailable (int w)
 	return true;
 }
 
+// [crispy] give or take backpack
+static void GiveBackpack (boolean give)
+{
+	int i;
+
+	if (give && !plyr->backpack)
+	{
+		for (i = 0; i < NUMAMMO; i++)
+		{
+			plyr->maxammo[i] *= 2;
+		}
+		plyr->backpack = true;
+	}
+	else
+	if (!give && plyr->backpack)
+	{
+		for (i = 0; i < NUMAMMO; i++)
+		{
+			plyr->maxammo[i] /= 2;
+		}
+		plyr->backpack = false;
+	}
+}
+
 // Respond to keyboard input events,
 //  intercept cheats.
 boolean
@@ -699,12 +737,7 @@ ST_Responder (event_t* ev)
 	plyr->armortype = deh_idfa_armor_class;
 	
 	// [crispy] give backpack
-	if (!plyr->backpack)
-	{
-	    for (i=0 ; i<NUMAMMO ; i++)
-		plyr->maxammo[i] *= 2;
-	    plyr->backpack = true;
-	}
+	GiveBackpack(true);
 
 	for (i=0;i<NUMWEAPONS;i++)
 	 if (WeaponAvailable(i)) // [crispy] only give available weapons
@@ -725,12 +758,7 @@ ST_Responder (event_t* ev)
 	plyr->armortype = deh_idkfa_armor_class;
 	
 	// [crispy] give backpack
-	if (!plyr->backpack)
-	{
-	    for (i=0 ; i<NUMAMMO ; i++)
-		plyr->maxammo[i] *= 2;
-	    plyr->backpack = true;
-	}
+	GiveBackpack(true);
 
 	for (i=0;i<NUMWEAPONS;i++)
 	 if (WeaponAvailable(i)) // [crispy] only give available weapons
@@ -766,6 +794,8 @@ ST_Responder (event_t* ev)
 	if (buf[0] == '0' && buf[1] == '0')
 	{
 	  S_ChangeMusic(0, 2);
+	  // [crispy] eat key press, i.e. don't change weapon upon music change
+	  return true;
 	}
 	else
 	// [JN] Fixed: using a proper IDMUS selection for shareware
@@ -782,7 +812,11 @@ ST_Responder (event_t* ev)
 	  if (musnum < mus_runnin || musnum >= NUMMUSIC)
 	    plyr->message = DEH_String(STSTR_NOMUS);
 	  else
+	  {
 	    S_ChangeMusic(musnum, 1);
+	    // [crispy] eat key press, i.e. don't change weapon upon music change
+	    return true;
+	  }
 	}
 	else
 	{
@@ -797,11 +831,21 @@ ST_Responder (event_t* ev)
 	      S_music[musnum].lumpnum == -1)
 	    plyr->message = DEH_String(STSTR_NOMUS);
 	  else
+	  {
 	    S_ChangeMusic(musnum, 1);
+	    // [crispy] eat key press, i.e. don't change weapon upon music change
+	    return true;
+	  }
 	}
+      }
+      // [crispy] eat up the first digit typed after a cheat expecting two parameters
+      else if (cht_CheckCheat(&cheat_mus1, ev->data2))
+      {
+	char buf[2];
 
-      // [crispy] eat key press, i.e. don't change weapon upon music change
-      return true;
+	cht_GetParam(&cheat_mus1, buf);
+
+	return isdigit(buf[0]);
       }
       // [crispy] allow both idspispopd and idclip cheats in all gamemissions
       else if ( ( /* logical_gamemission == doom
@@ -968,6 +1012,35 @@ ST_Responder (event_t* ev)
 	cht_GetParam(&cheat_weapon, buf);
 	w = *buf - '1';
 
+	// [crispy] TNTWEAP0 takes away all weapons and ammo except for the pistol and 50 bullets
+	if (w == -1)
+	{
+	    GiveBackpack(false);
+	    plyr->powers[pw_strength] = 0;
+
+	    for (i = 0; i < NUMWEAPONS; i++)
+	    {
+		oldweaponsowned[i] = plyr->weaponowned[i] = false;
+	    }
+	    oldweaponsowned[wp_fist] = plyr->weaponowned[wp_fist] = true;
+	    oldweaponsowned[wp_pistol] = plyr->weaponowned[wp_pistol] = true;
+
+	    for (i = 0; i < NUMAMMO; i++)
+	    {
+		plyr->ammo[i] = 0;
+	    }
+	    plyr->ammo[am_clip] = deh_initial_bullets;
+
+	    if (plyr->readyweapon > wp_pistol)
+	    {
+		plyr->pendingweapon = wp_pistol;
+	    }
+
+	    plyr->message = "All weapons removed!";
+
+	    return true;
+	}
+
 	// [crispy] only give available weapons
 	if (!WeaponAvailable(w))
 	    return false;
@@ -1074,7 +1147,7 @@ ST_Responder (event_t* ev)
     }
     
     // 'clev' change-level cheat
-    if (!netgame && !menuactive && cht_CheckCheatSP(&cheat_clev, ev->data2)) // [crispy] restrict cheat usage
+    if (!netgame && cht_CheckCheat(&cheat_clev, ev->data2) && !menuactive) // [crispy] prevent only half the screen being updated
     {
       char		buf[3];
       int		epsd;
@@ -1187,11 +1260,35 @@ ST_Responder (event_t* ev)
       {
       // So be it.
       plyr->message = DEH_String(STSTR_CLEV);
-      G_DeferedInitNew(gameskill, epsd, map);
+      // [crisp] allow IDCLEV during demo playback and warp to the requested map
+      if (demoplayback)
+      {
+          if (map > gamemap)
+          {
+              crispy->demowarp = map;
+              nodrawers = true;
+              singletics = true;
+              return true;
+          }
+          else
+          {
+              return false;
+          }
       }
-
+      else
+      G_DeferedInitNew(gameskill, epsd, map);
       // [crispy] eat key press, i.e. don't change weapon upon level change
       return true;
+      }
+    }
+    // [crispy] eat up the first digit typed after a cheat expecting two parameters
+    else if (!netgame && cht_CheckCheat(&cheat_clev1, ev->data2) && !menuactive)
+    {
+	char buf[2];
+
+	cht_GetParam(&cheat_clev1, buf);
+
+	return isdigit(buf[0]);
     }
   }
   return false;
@@ -1222,6 +1319,8 @@ int ST_calcPainOffset(void)
 // the precedence of expressions is:
 //  dead > evil grin > turned head > straight ahead
 //
+// [crispy] fix status bar face hysteresis
+static int faceindex;
 void ST_updateFaceWidget(void)
 {
     int		i;
@@ -1233,7 +1332,6 @@ void ST_updateFaceWidget(void)
 
     // [crispy] fix status bar face hysteresis
     int		painoffset;
-    static int	faceindex;
     // [crispy] no evil grin or rampage face in god mode
     const boolean invul = (plyr->cheats & CF_GODMODE) || plyr->powers[pw_invulnerability];
 
@@ -1457,14 +1555,14 @@ void ST_updateWidgets(void)
 		}
 #endif
 #if defined(CRISPY_KEYBLINK_IN_CLASSIC_HUD)
-		if (screenblocks < CRISPY_HUD && !(plyr->tryopen[i] & (KEYBLINKMASK-1)))
+		if (st_classicstatusbar && !(plyr->tryopen[i] & (KEYBLINKMASK-1)))
 		{
 			st_firsttime = true;
 		}
 #endif
 		plyr->tryopen[i]--;
 #if !defined(CRISPY_KEYBLINK_IN_CLASSIC_HUD)
-		if (screenblocks >= CRISPY_HUD)
+		if (st_crispyhud)
 #endif
 		{
 			keyboxes[i] = (plyr->tryopen[i] & KEYBLINKMASK) ? i + st_keyorskull[i] : -1;
@@ -1746,35 +1844,31 @@ void ST_drawWidgets(boolean refresh)
     dp_translation = NULL;
 
     // [crispy] draw "special widgets" in the Crispy HUD
-    if (screenblocks >= CRISPY_HUD && (!automapactive || crispy->automapoverlay))
+    if (st_crispyhud)
     {
 	// [crispy] draw berserk pack instead of no ammo if appropriate
 	if (plyr->readyweapon == wp_fist && plyr->powers[pw_strength])
 	{
-		static patch_t *patch;
+		static int lump = -1;
+		patch_t *patch;
 
-		if (!patch)
+		if (lump == -1)
 		{
-			const int lump = W_CheckNumForName(DEH_String("PSTRA0"));
+			lump = W_CheckNumForName(DEH_String("PSTRA0"));
 
-			if (lump >= 0)
+			if (lump == -1)
 			{
-				patch = W_CacheLumpNum(lump, PU_STATIC);
-			}
-			// [crispy] should you ever play with the IDBEHOLDS cheat and the Shareware version...
-			else
-			{
-				patch = W_CacheLumpName("MEDIA0", PU_STATIC);
+				lump = W_CheckNumForName(DEH_String("MEDIA0"));
 			}
 		}
 
-		if (patch)
-		{
-			// [crispy] (23,179) is the center of the Ammo widget
-			V_DrawPatch(23 - SHORT(patch->width)/2 + SHORT(patch->leftoffset),
-			            179 - SHORT(patch->height)/2 + SHORT(patch->topoffset),
-			            patch);
-		}
+		patch = W_CacheLumpNum(lump, PU_CACHE);
+
+		// [crispy] (23,179) is the center of the Ammo widget
+		V_DrawPatch(23 - SHORT(patch->width)/2 + SHORT(patch->leftoffset),
+		            179 - SHORT(patch->height)/2 + SHORT(patch->topoffset),
+		            patch);
+
 	}
 
 	// [crispy] draw the gibbed death state frames in the Health widget
@@ -1795,33 +1889,34 @@ void ST_drawWidgets(boolean refresh)
     if (!gibbed)
     {
     dp_translation = ST_WidgetColor(hudcolor_health);
-    STlib_updatePercent(&w_health, refresh || screenblocks >= CRISPY_HUD);
+    STlib_updatePercent(&w_health, refresh);
     }
     dp_translation = ST_WidgetColor(hudcolor_armor);
-    STlib_updatePercent(&w_armor, refresh || screenblocks >= CRISPY_HUD);
+    STlib_updatePercent(&w_armor, refresh);
     dp_translation = NULL;
 
-    if (screenblocks < CRISPY_HUD || (automapactive && !crispy->automapoverlay))
-    {
     STlib_updateBinIcon(&w_armsbg, refresh);
-    }
 
     // [crispy] show SSG availability in the Shotgun slot of the arms widget
     st_shotguns = plyr->weaponowned[wp_shotgun] | plyr->weaponowned[wp_supershotgun];
 
     for (i=0;i<6;i++)
-	STlib_updateMultIcon(&w_arms[i], refresh || screenblocks >= CRISPY_HUD);
+	STlib_updateMultIcon(&w_arms[i], refresh);
 
-    if (screenblocks < CRISPY_HUD || (automapactive && !crispy->automapoverlay))
+    // [crispy] draw the actual face widget background
+    if (st_crispyhud && screenblocks == CRISPY_HUD)
     {
-    STlib_updateMultIcon(&w_faces, refresh);
+	V_CopyRect(ST_FX, 1, st_backing_screen, SHORT(faceback->width), ST_HEIGHT - 1, ST_FX, ST_Y + 1);
     }
 
+    STlib_updateMultIcon(&w_faces, refresh);
+
     for (i=0;i<3;i++)
-	STlib_updateMultIcon(&w_keyboxes[i], refresh || screenblocks >= CRISPY_HUD);
+	STlib_updateMultIcon(&w_keyboxes[i], refresh);
 
     dp_translation = ST_WidgetColor(hudcolor_frags);
-    STlib_updateNum(&w_frags, refresh || screenblocks >= CRISPY_HUD);
+    STlib_updateNum(&w_frags, refresh);
+
     dp_translation = NULL;
 }
 
@@ -1831,7 +1926,7 @@ void ST_doRefresh(void)
     st_firsttime = false;
 
     // draw status bar background to off-screen buff
-    ST_refreshBackground();
+    ST_refreshBackground(false);
 
     // and refresh all widgets
     ST_drawWidgets(true);
@@ -1847,10 +1942,15 @@ void ST_diffDraw(void)
 void ST_Drawer (boolean fullscreen, boolean refresh)
 {
   
-    st_statusbaron = (!fullscreen) || (automapactive && !crispy->automapoverlay) || screenblocks >= CRISPY_HUD;
+    st_statusbaron = (!fullscreen) || (automapactive && !crispy->automapoverlay);
     // [crispy] immediately redraw status bar after help screens have been shown
     st_firsttime = st_firsttime || refresh || inhelpscreens;
 
+    // [crispy] distinguish classic status bar with background and player face from Crispy HUD
+    st_crispyhud = screenblocks >= CRISPY_HUD && (!automapactive || crispy->automapoverlay);
+    st_classicstatusbar = st_statusbaron && !st_crispyhud;
+    st_statusbarface = st_classicstatusbar || (st_crispyhud && screenblocks == CRISPY_HUD);
+
     if (crispy->cleanscreenshot == 2)
         return;
 
@@ -1858,7 +1958,7 @@ void ST_Drawer (boolean fullscreen, boolean refresh)
     ST_doPaletteStuff();
 
     // [crispy] translucent HUD
-    if (screenblocks > CRISPY_HUD && !(automapactive && !crispy->automapoverlay))
+    if (st_crispyhud && screenblocks > CRISPY_HUD + 1)
 	dp_translucent = true;
 
     // If just after ST_Start(), refresh all
@@ -1866,8 +1966,7 @@ void ST_Drawer (boolean fullscreen, boolean refresh)
     // Otherwise, update as little as possible
     else ST_diffDraw();
 
-    if (dp_translucent)
-	dp_translucent = false;
+    dp_translucent = false;
 }
 
 typedef void (*load_callback_t)(const char *lumpname, patch_t **variable);
@@ -1926,7 +2025,16 @@ static void ST_loadUnloadGraphics(load_callback_t callback)
     callback(namebuf, &faceback);
 
     // status bar background bits
-    callback(DEH_String("STBAR"), &sbar);
+    if (W_CheckNumForName("STBAR") >= 0)
+    {
+        callback(DEH_String("STBAR"), &sbar);
+        sbarr = NULL;
+    }
+    else
+    {
+        callback(DEH_String("STMBARL"), &sbar);
+        callback(DEH_String("STMBARR"), &sbarr);
+    }
 
     // face states
     facenum = 0;
@@ -2024,6 +2132,7 @@ void ST_initData(void)
     st_oldchat = st_chat = false;
     st_cursoron = false;
 
+    faceindex = 0; // [crispy] fix status bar face hysteresis across level changes
     st_faceindex = 0;
     st_palette = -1;
 
@@ -2073,7 +2182,7 @@ void ST_createWidgets(void)
 		      ST_ARMSBGY,
 		      armsbg,
 		      &st_notdeathmatch,
-		      &st_statusbaron);
+		      &st_classicstatusbar);
 
     // weapons owned
     for(i=0;i<6;i++)
@@ -2103,7 +2212,7 @@ void ST_createWidgets(void)
 		       ST_FACESY,
 		       faces,
 		       &st_faceindex,
-		       &st_statusbaron);
+		       &st_statusbarface);
 
     // armor percentage - should be colored later
     STlib_initPercent(&w_armor,
