@@ -699,7 +699,7 @@ WI_drawNum
     }
 
     // draw a minus sign if necessary
-    if (neg)
+    if (neg && wiminus)
 	V_DrawPatch(x-=8, y, wiminus);
 
     return x;
@@ -1591,12 +1591,7 @@ void WI_drawStats(void)
     if (WI_drawParTime())
     {
         V_DrawPatch(ORIGWIDTH/2 + SP_TIMEX, SP_TIMEY, par);
-
-        // Emulation: don't draw partime value if map33
-        if (gamemode != commercial || wbs->last != NUMCMAPS)
-        {
-            WI_drawTime(ORIGWIDTH - SP_TIMEX, SP_TIMEY, cnt_par, true);
-        }
+        WI_drawTime(ORIGWIDTH - SP_TIMEX, SP_TIMEY, cnt_par, true);
     }
 
     // [crispy] draw total time after level time and par time
@@ -1610,6 +1605,12 @@ void WI_drawStats(void)
 	WI_drawTime((wide ? ORIGWIDTH : ORIGWIDTH/2) - SP_TIMEX, SP_TIMEY + 16, ttime, false);
     }
 
+    // [crispy] exit early from the tally screen after ExM8
+    if (sp_state == 10 && gamemode != commercial && gamemap == 8)
+    {
+	acceleratestage = 1;
+    }
+
     // [crispy] demo timer widget
     if ((demoplayback && (crispy->demotimer & DEMOTIMER_PLAYBACK)) ||
         (demorecording && (crispy->demotimer & DEMOTIMER_RECORD)))
@@ -1778,7 +1779,10 @@ static void WI_loadUnloadData(load_callback_t callback)
     }
 
     // More hacks on minus sign.
-    callback(DEH_String("WIMINUS"), &wiminus);
+    if (W_CheckNumForName(DEH_String("WIMINUS")) > 0)
+        callback(DEH_String("WIMINUS"), &wiminus);
+    else
+        wiminus = NULL;
 
     for (i=0;i<10;i++)
     {
