@@ -25,6 +25,7 @@
 #include <stdlib.h>
 
 #include "doomdef.h"
+#include "i_system.h" // [crispy] I_Realloc()
 #include "r_local.h"
 
 // OPTIMIZE: closed two sided lines as single sided
@@ -347,7 +348,7 @@ void R_StoreWallRange(int start, int stop)
 	int numdrawsegs_old = numdrawsegs;
 
 	numdrawsegs = numdrawsegs ? 2 * numdrawsegs : MAXDRAWSEGS;
-	drawsegs = realloc(drawsegs, numdrawsegs * sizeof(*drawsegs));
+	drawsegs = I_Realloc(drawsegs, numdrawsegs * sizeof(*drawsegs));
 	memset(drawsegs + numdrawsegs_old, 0, (numdrawsegs - numdrawsegs_old) * sizeof(*drawsegs));
 
 	ds_p = drawsegs + numdrawsegs_old;
