@@ -57,7 +57,7 @@ int viewangletox[FINEANGLES / 2];
 
 // The xtoviewangleangle[] table maps a screen pixel to the lowest viewangle
 // that maps back to x ranges from clipangle to -clipangle
-angle_t xtoviewangle[SCREENWIDTH + 1];
+angle_t xtoviewangle[MAXWIDTH + 1];
 
 lighttable_t *scalelight[LIGHTLEVELS][MAXLIGHTSCALE];
 lighttable_t *scalelightfixed[MAXLIGHTSCALE];
@@ -560,8 +560,8 @@ void R_ExecuteSetViewSize(void)
     }
     else
     {
-        scaledviewwidth = (setblocks * 32) << hires;
-        viewheight = (setblocks * 161 / 10) << hires;
+        scaledviewwidth = (setblocks * 32) << crispy->hires;
+        viewheight = (setblocks * 161 / 10) << crispy->hires;
     }
 
     detailshift = setdetail;
@@ -734,7 +734,7 @@ void R_SetupFrame(player_t * player)
     extralight = player->extralight;
     viewz = player->viewz;
 
-    tempCentery = viewheight / 2 + ((player->lookdir) << hires) * screenblocks / 10;
+    tempCentery = viewheight / 2 + ((player->lookdir) << crispy->hires) * screenblocks / 10;
     if (centery != tempCentery)
     {
         centery = tempCentery;
