@@ -1448,7 +1448,7 @@ static default_t extra_defaults_list[] =
     CONFIG_VARIABLE_KEY(key_menu_nextlevel),
 
     //!
-    // Keyboard shortcut to reload current level.
+    // Keyboard shortcut to restart current level or demo.
     //
 
     CONFIG_VARIABLE_KEY(key_menu_reloadlevel),
@@ -1817,6 +1817,14 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_INT(crispy_automapstats),
 
+    //!
+    // @game doom
+    //
+    // Variable player view bob.
+    //
+
+    CONFIG_VARIABLE_INT(crispy_bobfactor),
+
     //!
     // @game doom
     //
@@ -2631,11 +2639,14 @@ static char *GetDefaultConfigDir(void)
     // Vanilla Doom and save in the current directory.
 
     char *result;
+    char *copy;
 
     result = SDL_GetPrefPath("", PACKAGE_TARNAME);
     if (result != NULL)
     {
-        return result;
+        copy = M_StringDuplicate(result);
+        SDL_free(result);
+        return copy;
     }
 #endif /* #ifndef _WIN32 */
     return M_StringDuplicate("");
