@@ -40,11 +40,9 @@
 #include "net_structrw.h"
 
 // How often to refresh our registration with the master server.
-
-#define MASTER_REFRESH_PERIOD 20 * 60 /* 20 minutes */
+#define MASTER_REFRESH_PERIOD 30  /* twice per minute */
 
 // How often to re-resolve the address of the master server?
-
 #define MASTER_RESOLVE_PERIOD 8 * 60 * 60 /* 8 hours */
 
 typedef enum
@@ -186,7 +184,8 @@ static boolean ClientConnected(net_client_t *client)
 
 // Send a message to be displayed on a client's console
 
-static void NET_SV_SendConsoleMessage(net_client_t *client, char *s, ...)
+static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...) PRINTF_ATTR(2, 3);
+static void NET_SV_SendConsoleMessage(net_client_t *client, const char *s, ...)
 {
     char buf[1024];
     va_list args;
@@ -204,7 +203,8 @@ static void NET_SV_SendConsoleMessage(net_client_t *client, char *s, ...)
 
 // Send a message to all clients
 
-static void NET_SV_BroadcastMessage(char *s, ...)
+static void NET_SV_BroadcastMessage(const char *s, ...) PRINTF_ATTR(1, 2);
+static void NET_SV_BroadcastMessage(const char *s, ...)
 {
     char buf[1024];
     va_list args;
@@ -218,7 +218,7 @@ static void NET_SV_BroadcastMessage(char *s, ...)
     {
         if (ClientConnected(&clients[i]))
         {
-            NET_SV_SendConsoleMessage(&clients[i], buf);
+            NET_SV_SendConsoleMessage(&clients[i], "%s", buf);
         }
     }
 
@@ -481,7 +481,7 @@ static void NET_SV_AdvanceWindow(void)
     // Advance the recv window until it catches up with lowtic
 
     while (recvwindow_start < lowtic)
-    {    
+    {
         boolean should_advance;
 
         // Check we have tics from all players for first tic in
@@ -518,8 +518,7 @@ static void NET_SV_AdvanceWindow(void)
                 sizeof(*recvwindow) * (BACKUPTICS - 1));
         memset(&recvwindow[BACKUPTICS-1], 0, sizeof(*recvwindow));
         ++recvwindow_start;
-
-        //printf("SV: advanced to %i\n", recvwindow_start);
+        NET_Log("server: advanced receive window to %d", recvwindow_start);
     }
 }
 
@@ -544,10 +543,12 @@ static net_client_t *NET_SV_FindClient(net_addr_t *addr)
 
 // send a rejection packet to a client
 
-static void NET_SV_SendReject(net_addr_t *addr, char *msg)
+static void NET_SV_SendReject(net_addr_t *addr, const char *msg)
 {
     net_packet_t *packet;
 
+    NET_Log("server: sending reject to %s", NET_AddrToString(addr));
+
     packet = NET_NewPacket(10);
     NET_WriteInt16(packet, NET_PACKET_TYPE_REJECTED);
     NET_WriteString(packet, msg);
@@ -562,6 +563,7 @@ static void NET_SV_InitNewClient(net_client_t *client, net_addr_t *addr,
     client->connect_time = I_GetTimeMS();
     NET_Conn_InitServer(&client->connection, addr, protocol);
     client->addr = addr;
+    NET_ReferenceAddress(addr);
     client->last_send_time = -1;
 
     // init the ticcmd send queue
@@ -574,6 +576,8 @@ static void NET_SV_InitNewClient(net_client_t *client, net_addr_t *addr,
     client->last_gamedata_time = 0;
 
     memset(client->sendqueue, 0xff, sizeof(client->sendqueue));
+
+    NET_Log("server: initialized new client from %s", NET_AddrToString(addr));
 }
 
 // parse a SYN from a client(initiating a connection)
@@ -590,9 +594,12 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     int num_players;
     int i;
 
+    NET_Log("server: processing SYN packet");
+
     // Read the magic number and check it is the expected one.
     if (!NET_ReadInt32(packet, &magic))
     {
+        NET_Log("server: error: no magic number for SYN");
         return;
     }
 
@@ -602,12 +609,14 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
             break;
 
         case NET_OLD_MAGIC_NUMBER:
+            NET_Log("server: error: client using old magic number: %d", magic);
             NET_SV_SendReject(addr,
                 "You are using an old client version that is not supported by "
                 "this server. This server is running " PACKAGE_STRING ".");
             return;
 
         default:
+            NET_Log("server: error: wrong magic number: %d", magic);
             return;
     }
 
@@ -617,6 +626,7 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     client_version = NET_ReadString(packet);
     if (client_version == NULL)
     {
+        NET_Log("server: error: no version from client");
         return;
     }
 
@@ -633,15 +643,24 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
             "client is: %s. No common compatible protocol could be "
             "negotiated.", client_version);
         NET_SV_SendReject(addr, reject_msg);
+        NET_Log("server: error: no common protocol");
         return;
     }
 
     // Read connect data, and check that the game mode/mission are valid
     // and the max_players value is in a sensible range.
-    if (!NET_ReadConnectData(packet, &data)
-     || !D_ValidGameMode(data.gamemission, data.gamemode)
+    if (!NET_ReadConnectData(packet, &data))
+    {
+        NET_Log("server: error: failed to read connect data");
+        return;
+    }
+
+    if (!D_ValidGameMode(data.gamemission, data.gamemode)
      || data.max_players > NET_MAXPLAYERS)
     {
+        NET_Log("server: error: invalid connect data, max_players=%d, "
+                "gamemission=%d, gamemode=%d",
+                data.max_players, data.gamemission, data.gamemode);
         return;
     }
 
@@ -649,6 +668,7 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     player_name = NET_ReadString(packet);
     if (player_name == NULL)
     {
+        NET_Log("server: error: failed to read player name");
         return;
     }
 
@@ -657,6 +677,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     // Not accepting new connections?
     if (server_state != SERVER_WAITING_LAUNCH)
     {
+        NET_Log("server: error: not in waiting launch state, server_state=%d",
+                server_state);
         NET_SV_SendReject(addr,
                           "Server is not currently accepting connections");
         return;
@@ -669,6 +691,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     if ((!data.drone && num_players >= NET_SV_MaxPlayers())
      || NET_SV_NumClients() >= MAXNETNODES)
     {
+        NET_Log("server: no more players, num_players=%d, max=%d",
+                num_players, NET_SV_MaxPlayers());
         NET_SV_SendReject(addr, "Server is full!");
         return;
     }
@@ -682,6 +706,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     {
         sv_gamemode = data.gamemode;
         sv_gamemission = data.gamemission;
+        NET_Log("server: new game, mode=%d, mission=%d",
+                sv_gamemode, sv_gamemission);
     }
 
     // Check the connecting client is playing the same game as all
@@ -689,6 +715,8 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     if (data.gamemode != sv_gamemode || data.gamemission != sv_gamemission)
     {
         char msg[128];
+        NET_Log("server: wrong mode/mission, %d != %d || %d != %d",
+                data.gamemode, sv_gamemode, data.gamemission, sv_gamemission);
         M_snprintf(msg, sizeof(msg),
                    "Game mismatch: server is %s (%s), client is %s (%s)",
                    D_GameMissionString(sv_gamemission),
@@ -733,6 +761,7 @@ static void NET_SV_ParseSYN(net_packet_t *packet, net_client_t *client,
     // Client already connected?
     if (client->active)
     {
+        NET_Log("server: client is already initialized (duplicate SYN?)");
         return;
     }
 
@@ -765,10 +794,14 @@ static void NET_SV_ParseLaunch(net_packet_t *packet, net_client_t *client)
     int num_players;
     unsigned int i;
 
+    NET_Log("server: processing launch packet");
+
     // Only the controller can launch the game.
 
     if (client != NET_SV_Controller())
     {
+        NET_Log("server: error: this client isn't the controller, %d != %d",
+                client, NET_SV_Controller());
         return;
     }
 
@@ -776,11 +809,13 @@ static void NET_SV_ParseLaunch(net_packet_t *packet, net_client_t *client)
 
     if (server_state != SERVER_WAITING_LAUNCH)
     {
+        NET_Log("server: error: not in waiting launch state, state=%d",
+                server_state);
         return;
     }
 
     // Forward launch on to all clients.
-
+    NET_Log("server: sending launch to all clients");
     NET_SV_AssignPlayers();
     num_players = NET_SV_NumPlayers();
 
@@ -861,7 +896,7 @@ static void StartGame(void)
     }
 
     // Change server state
-
+    NET_Log("server: beginning game state");
     server_state = SERVER_IN_GAME;
 
     memset(recvwindow, 0, sizeof(recvwindow));
@@ -889,10 +924,14 @@ static boolean AllNodesReady(void)
 
 static void CheckStartGame(void)
 {
-    if (AllNodesReady())
+    if (!AllNodesReady())
     {
-        StartGame();
+        NET_Log("server: not all clients ready to start yet");
+        return;
     }
+
+    NET_Log("server: all clients ready, starting game");
+    StartGame();
 }
 
 // Send waiting data with current status to all nodes that are ready to
@@ -917,10 +956,14 @@ static void NET_SV_ParseGameStart(net_packet_t *packet, net_client_t *client)
 {
     net_gamesettings_t settings;
 
+    NET_Log("server: processing game start packet");
+
     // Can only start a game if we are in the waiting start state.
 
     if (server_state != SERVER_WAITING_START)
     {
+        NET_Log("server: error: not in waiting start state, server_state=%d",
+                server_state);
         return;
     }
 
@@ -929,7 +972,7 @@ static void NET_SV_ParseGameStart(net_packet_t *packet, net_client_t *client)
         if (!NET_ReadSettings(packet, &settings))
         {
             // Malformed packet
-
+            NET_Log("server: error: no settings from controller");
             return;
         }
 
@@ -937,6 +980,7 @@ static void NET_SV_ParseGameStart(net_packet_t *packet, net_client_t *client)
 
         if (!NET_ValidGameSettings(sv_gamemode, sv_gamemission, &settings))
         {
+            NET_Log("server: error: invalid game settings");
             return;
         }
 
@@ -964,7 +1008,8 @@ static void NET_SV_SendResendRequest(net_client_t *client, int start, int end)
     unsigned int nowtime;
     int index;
 
-    //printf("SV: send resend for %i-%i\n", start, end);
+    NET_Log("server: send resend to %s for tics %d-%d",
+            NET_AddrToString(client->addr), start, end);
 
     packet = NET_NewPacket(20);
 
@@ -1028,33 +1073,36 @@ static void NET_SV_CheckResends(net_client_t *client)
         if (need_resend)
         {
             // Start a new run of resend tics?
- 
             if (resend_start < 0)
             {
                 resend_start = i;
             }
-            
             resend_end = i;
         }
-        else
+        else if (resend_start >= 0)
         {
-            if (resend_start >= 0)
-            {
-                // End of a run of resend tics
+            // End of a run of resend tics
+            NET_Log("server: resend request to %s timed out for %d-%d (%d)",
+                    NET_AddrToString(client->addr),
+                    recvwindow_start + resend_start,
+                    recvwindow_start + resend_end,
+                    &recvwindow[resend_start][player].resend_time);
+            NET_SV_SendResendRequest(client, 
+                                     recvwindow_start + resend_start,
+                                     recvwindow_start + resend_end);
 
-                //printf("SV: resend request timed out: %i-%i\n", resend_start, resend_end);
-                NET_SV_SendResendRequest(client, 
-                                         recvwindow_start + resend_start,
-                                         recvwindow_start + resend_end);
-
-                resend_start = -1;
-            }
+            resend_start = -1;
         }
     }
 
     if (resend_start >= 0)
     {
-        NET_SV_SendResendRequest(client, 
+        NET_Log("server: resend request to %s timed out for %d-%d (%d)",
+                NET_AddrToString(client->addr),
+                recvwindow_start + resend_start,
+                recvwindow_start + resend_end,
+                &recvwindow[resend_start][player].resend_time);
+        NET_SV_SendResendRequest(client,
                                  recvwindow_start + resend_start,
                                  recvwindow_start + resend_end);
     }
@@ -1076,32 +1124,36 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
 
     if (server_state != SERVER_IN_GAME)
     {
+        NET_Log("server: error: not in game state: server_state=%d",
+                server_state);
         return;
     }
 
     if (client->drone)
     {
         // Drones do not contribute any game data.
+        NET_Log("server: error: game data from a drone?");
         return;
     }
 
     player = client->player_number;
 
     // Read header
-
     if (!NET_ReadInt8(packet, &ackseq)
      || !NET_ReadInt8(packet, &seq)
      || !NET_ReadInt8(packet, &num_tics))
     {
+        NET_Log("server: error: failed to read header");
         return;
     }
 
-    // Get the current time
+    NET_Log("server: got game data, seq=%d, num_tics=%d, ackseq=%d",
+            seq, num_tics, ackseq);
 
+    // Get the current time
     nowtime = I_GetTimeMS();
 
     // Expand 8-bit values to the full sequence number
-
     ackseq = NET_SV_ExpandTicNum(ackseq);
     seq = NET_SV_ExpandTicNum(seq);
 
@@ -1133,12 +1185,14 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
         recvobj->latency = latency;
 
         client->last_gamedata_time = nowtime;
+        NET_Log("server: stored tic %d for player %d", seq + i, player);
     }
 
     // Higher acknowledgement point?
 
     if (ackseq > client->acknowledged)
     {
+        NET_Log("server: acknowledged up to %d", ackseq);
         client->acknowledged = ackseq;
     }
 
@@ -1182,15 +1236,11 @@ static void NET_SV_ParseGameData(net_packet_t *packet, net_client_t *client)
     }
 
     // Possibly send a resend request
-
     if (resend_start < resend_end)
     {
-            /*
-        printf("missed %i-%i before %i, send resend\n",
-                        recvwindow_start + resend_start,
-                        recvwindow_start + resend_end - 1,
-                        seq);
-                        */
+        NET_Log("server: request resend for %d-%d before %d",
+                recvwindow_start + resend_start,
+                recvwindow_start + resend_end - 1, seq);
         NET_SV_SendResendRequest(client, 
                                  recvwindow_start + resend_start, 
                                  recvwindow_start + resend_end - 1);
@@ -1201,8 +1251,12 @@ static void NET_SV_ParseGameDataACK(net_packet_t *packet, net_client_t *client)
 {
     unsigned int ackseq;
 
+    NET_Log("server: processing game data ack packet");
+
     if (server_state != SERVER_IN_GAME)
     {
+        NET_Log("server: error: not in game state, server_state=%d",
+                server_state);
         return;
     }
 
@@ -1210,6 +1264,7 @@ static void NET_SV_ParseGameDataACK(net_packet_t *packet, net_client_t *client)
 
     if (!NET_ReadInt8(packet, &ackseq))
     {
+        NET_Log("server: error: missing acknowledgement field");
         return;
     }
 
@@ -1221,6 +1276,7 @@ static void NET_SV_ParseGameDataACK(net_packet_t *packet, net_client_t *client)
 
     if (ackseq > client->acknowledged)
     {
+        NET_Log("server: acknowledged up to %d", ackseq);
         client->acknowledged = ackseq;
     }
 }
@@ -1273,11 +1329,14 @@ static void NET_SV_ParseResendRequest(net_packet_t *packet, net_client_t *client
     unsigned int num_tics;
     unsigned int i;
 
+    NET_Log("server: processing resend request");
+
     // Read the starting tic and number of tics
 
     if (!NET_ReadInt32(packet, &start)
      || !NET_ReadInt8(packet, &num_tics))
     {
+        NET_Log("server: error: missing fields for resend");
         return;
     }
 
@@ -1299,13 +1358,14 @@ static void NET_SV_ParseResendRequest(net_packet_t *packet, net_client_t *client
             // This is pretty fatal.  We could disconnect the client, 
             // but then again this could be a spoofed packet.  Just 
             // ignore it.
-
+            NET_Log("server: error: don't have tic %d any more, "
+                    "can't resend", i);
             return;
         }
     }
 
     // Resend those tics
-
+    NET_Log("server: resending tics %d-%d", start, last);
     NET_SV_SendTics(client, start, last);
 }
 
@@ -1354,7 +1414,7 @@ void NET_SV_SendQueryResponse(net_addr_t *addr)
     }
 
     // Send it and we're done.
-
+    NET_Log("server: sending query response to %s", NET_AddrToString(addr));
     reply = NET_NewPacket(64);
     NET_WriteInt16(reply, NET_PACKET_TYPE_QUERY_RESPONSE);
     NET_WriteQueryData(reply, &querydata);
@@ -1362,6 +1422,61 @@ void NET_SV_SendQueryResponse(net_addr_t *addr)
     NET_FreePacket(reply);
 }
 
+static void NET_SV_ParseHolePunch(net_packet_t *packet)
+{
+    const char *addr_string;
+    net_packet_t *sendpacket;
+    net_addr_t *addr;
+
+    addr_string = NET_ReadString(packet);
+    if (addr_string == NULL)
+    {
+        NET_Log("server: error: hole punch request but no address provided");
+        return;
+    }
+
+    addr = NET_ResolveAddress(server_context, addr_string);
+    if (addr == NULL)
+    {
+        NET_Log("server: error: failed to resolve address: %s", addr_string);
+        return;
+    }
+
+    sendpacket = NET_NewPacket(16);
+    NET_WriteInt16(sendpacket, NET_PACKET_TYPE_NAT_HOLE_PUNCH);
+    NET_SendPacket(addr, sendpacket);
+    NET_FreePacket(sendpacket);
+    NET_ReleaseAddress(addr);
+    NET_Log("server: sent hole punch to %s", addr_string);
+}
+
+static void NET_SV_MasterPacket(net_packet_t *packet)
+{
+    unsigned int packet_type;
+
+    // Read the packet type
+
+    if (!NET_ReadInt16(packet, &packet_type))
+    {
+        NET_Log("server: error: no packet type in master server message");
+        return;
+    }
+
+    NET_Log("server: packet from master server; type %d", packet_type);
+    NET_LogPacket(packet);
+
+    switch (packet_type)
+    {
+        case NET_MASTER_PACKET_TYPE_ADD_RESPONSE:
+            NET_Query_AddResponse(packet);
+            break;
+
+        case NET_MASTER_PACKET_TYPE_NAT_HOLE_PUNCH:
+            NET_SV_ParseHolePunch(packet);
+            break;
+    }
+}
+
 // Process a packet received by the server
 
 static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
@@ -1373,7 +1488,7 @@ static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
 
     if (addr != NULL && addr == master_server)
     {
-        NET_Query_MasterResponse(packet);
+        NET_SV_MasterPacket(packet);
         return;
     }
 
@@ -1390,6 +1505,10 @@ static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
         return;
     }
 
+    NET_Log("server: packet from %s; type %d", NET_AddrToString(addr),
+            packet_type & ~NET_RELIABLE_PACKET);
+    NET_LogPacket(packet);
+
     if (packet_type == NET_PACKET_TYPE_SYN)
     {
         NET_SV_ParseSYN(packet, client, addr);
@@ -1433,14 +1552,6 @@ static void NET_SV_Packet(net_packet_t *packet, net_addr_t *addr)
                 break;
         }
     }
-
-    // If this address is not in the list of clients, be sure to
-    // free it back.
-
-    if (NET_SV_FindClient(addr) == NULL)
-    {
-        NET_FreeAddress(addr);
-    }
 }
 
 
@@ -1510,8 +1621,6 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
         return;
     }
 
-    //printf("SV: have complete ticcmd for %i\n", client->sendseq);
-
     // We have all data we need to generate a command for this tic.
     
     cmd.seq = client->sendseq;
@@ -1562,6 +1671,8 @@ static void NET_SV_PumpSendQueue(net_client_t *client)
     if (starttic < 0)
         starttic = 0;
 
+    NET_Log("server: send tics %d-%d to %s", starttic, endtic,
+            NET_AddrToString(client->addr));
     NET_SV_SendTics(client, starttic, endtic);
 
     ++client->sendseq;
@@ -1592,6 +1703,10 @@ void NET_SV_CheckDeadlock(net_client_t *client)
 
     if (nowtime - client->last_gamedata_time > 1000)
     {
+        NET_Log("server: no gamedata from %s since %d - deadlock?",
+                NET_AddrToString(client->addr),
+                client->last_gamedata_time);
+
         // Search the receive window for the first tic we are expecting
         // from this player.
 
@@ -1599,7 +1714,8 @@ void NET_SV_CheckDeadlock(net_client_t *client)
         {
             if (!recvwindow[client->player_number][i].active)
             {
-                //printf("Possible deadlock: Sending resend request\n");
+                NET_Log("server: deadlock: sending resend request for %d-%d",
+                        recvwindow_start + i, recvwindow_start + i + 5);
 
                 // Found a tic we haven't received.  Send a resend request.
 
@@ -1611,6 +1727,18 @@ void NET_SV_CheckDeadlock(net_client_t *client)
                 break;
             }
         }
+
+        // If we sent a resend request to break the deadlock, also trigger a
+        // resend of any tics we have sitting in the send queue, in case the
+        // client is blocked waiting on tics from us that have been lost.
+        // This fixes deadlock with some older clients which do not send
+        // resends to break deadlock.
+        if (i < BACKUPTICS && client->sendseq > client->acknowledged)
+        {
+            NET_Log("server: also resending tics %d-%d to break deadlock",
+                    client->acknowledged, client->sendseq - 1);
+            NET_SV_SendTics(client, client->acknowledged, client->sendseq - 1);
+        }
     }
 }
 
@@ -1640,14 +1768,16 @@ static void NET_SV_RunClient(net_client_t *client)
     // Run common code
 
     NET_Conn_Run(&client->connection);
-    
+
     if (client->connection.state == NET_CONN_STATE_DISCONNECTED
      && client->connection.disconnect_reason == NET_DISCONNECT_TIMEOUT)
     {
+        NET_Log("server: client at %s timed out",
+                NET_AddrToString(client->addr));
         NET_SV_BroadcastMessage("Client '%s' timed out and disconnected",
                                 client->name);
     }
-    
+
     // Is this client disconnected?
 
     if (client->connection.state == NET_CONN_STATE_DISCONNECTED)
@@ -1666,7 +1796,7 @@ static void NET_SV_RunClient(net_client_t *client)
         }
 
         free(client->name);
-        NET_FreeAddress(client->addr);
+        NET_ReleaseAddress(client->addr);
 
         // Are there any clients left connected?  If not, return the
         // server to the waiting-for-players state.
@@ -1675,6 +1805,7 @@ static void NET_SV_RunClient(net_client_t *client)
 
         if (NET_SV_NumPlayers() <= 0)
         {
+            NET_Log("server: no player clients left, game ended");
             NET_SV_GameEnded();
         }
     }
@@ -1753,14 +1884,8 @@ static void UpdateMasterServer(void)
         net_addr_t *new_addr;
 
         new_addr = NET_Query_ResolveMaster(server_context);
-
-        // Has the master server changed address?
-
-        if (new_addr != NULL && new_addr != master_server)
-        {
-            NET_FreeAddress(master_server);
-            master_server = new_addr;
-        }
+        NET_ReleaseAddress(master_server);
+        master_server = new_addr;
 
         master_resolve_time = now;
     }
@@ -1820,6 +1945,7 @@ void NET_SV_Run(void)
     {
         NET_SV_Packet(packet, addr);
         NET_FreePacket(packet);
+        NET_ReleaseAddress(addr);
     }
 
     if (master_server != NULL)
